/* $Id: Composite.h,v 1.4 1999/11/06 05:50:57 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 Copyright (C) 1999       Gerald L. Gay
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(xarm_composite_h)
#define xarm_composite_h

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Core.h>

class CompositeClass : public CoreClass {
 protected:
   CompositeClass() {}

   virtual WidgetClass classPointer()   { return compositeWidgetClass; }
   virtual _XtString className()        { return (_XtString) "Composite"; }
 public:
   void insertPosition(XtOrderProc val) { XARM_SET_VALUE(XmNinsertPosition); }
   WidgetList children() const          { XARM_GET_VALUE(WidgetList, XmNchildren); }
   int numChildren() const              { XARM_GET_VALUE(int, XmNnumChildren); }
};

#endif
